@@ -18,8 +18,10 @@ def authenticated_get(url, params={}, headers={}):
     headers['Client-ID'] = CLIENT_ID
 
     response = requests.get(url, params, headers=headers)
-    if response.status_code == 400:
+    if 400 <= response.status_code < 500:
         data = response.json()
+        # TODO: this does not look nice in the console since data["message"]
+        # can contain a JSON encoded object.
         raise ConsoleError(data["message"])
 
     response.raise_for_status()
